Multiple 1D spectra with manual adjustment of vertical axis (*)
===============================================================

This plot is identical to Figure 8 of *Anal. Chem.* **2021,** *93* (31), 10735–10739 [`DOI <https://doi.org/10.1021/acs.analchem.1c01767>`_].

The aim is to show that the water peak (middle row) can be suppressed adequately, while leaving the desired peaks untouched (top and bottom rows).

.. plot:: gallery/multiple_1d_yaxis.py

